# ConnectorForwarderStatsPublish

Published forwarder statistics for a connector instance, broken down by 'type' of forwarder. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**forwarder_totals** | [**ForwarderCommonStats**](ForwarderCommonStats.md) |  | 
**service_forwarder_stats** | [**[ForwarderStatsPublish]**](ForwarderStatsPublish.md) | The stats for normal service forwarders  | 
**internal_forwarder_stats** | [**[ForwarderStatsPublish]**](ForwarderStatsPublish.md) | The stats for internal service forwarders  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


